pub struct EchoEchoStringResponse {
pub response: String,
}Fields
response: StringTrait Implementations
Sourceimpl Clone for EchoEchoStringResponse
impl Clone for EchoEchoStringResponse
Sourcefn clone(&self) -> EchoEchoStringResponse
fn clone(&self) -> EchoEchoStringResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<EchoEchoStringResponse> for EchoEchoStringResponse
impl CompatFrom<EchoEchoStringResponse> for EchoEchoStringResponse
Sourcefn compat_from(value: EchoEchoStringResponse) -> EchoEchoStringResponse
fn compat_from(value: EchoEchoStringResponse) -> EchoEchoStringResponse
Converts
value into a value of this type.Sourceimpl Debug for EchoEchoStringResponse
impl Debug for EchoEchoStringResponse
Sourceimpl<'a, ___E> Encode<EchoEchoStringResponse<'static>, ___E> for &'a EchoEchoStringResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<EchoEchoStringResponse<'static>, ___E> for &'a EchoEchoStringResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EchoEchoStringResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EchoEchoStringResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EchoEchoStringResponse<'static>, ___E> for EchoEchoStringResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<EchoEchoStringResponse<'static>, ___E> for EchoEchoStringResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EchoEchoStringResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EchoEchoStringResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, EchoEchoStringResponse<'static>>, ___E> for &'a EchoEchoStringResponsewhere
___E: Encoder + ?Sized,
&'a EchoEchoStringResponse: Encode<EchoEchoStringResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, EchoEchoStringResponse<'static>>, ___E> for &'a EchoEchoStringResponsewhere
___E: Encoder + ?Sized,
&'a EchoEchoStringResponse: Encode<EchoEchoStringResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a EchoEchoStringResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EchoEchoStringResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a EchoEchoStringResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EchoEchoStringResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, EchoEchoStringResponse<'static>>, ___E> for EchoEchoStringResponsewhere
___E: Encoder + ?Sized,
EchoEchoStringResponse: Encode<EchoEchoStringResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, EchoEchoStringResponse<'static>>, ___E> for EchoEchoStringResponsewhere
___E: Encoder + ?Sized,
EchoEchoStringResponse: Encode<EchoEchoStringResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<EchoEchoStringResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EchoEchoStringResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<EchoEchoStringResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EchoEchoStringResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<EchoEchoStringResponse<'de>> for EchoEchoStringResponse
impl<'de> FromWire<EchoEchoStringResponse<'de>> for EchoEchoStringResponse
Sourcefn from_wire(wire: EchoEchoStringResponse<'de>) -> EchoEchoStringResponse
fn from_wire(wire: EchoEchoStringResponse<'de>) -> EchoEchoStringResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<EchoEchoStringResponse<'de>> for EchoEchoStringResponse
impl<'de> FromWireRef<EchoEchoStringResponse<'de>> for EchoEchoStringResponse
Sourcefn from_wire_ref(wire: &EchoEchoStringResponse<'de>) -> EchoEchoStringResponse
fn from_wire_ref(wire: &EchoEchoStringResponse<'de>) -> EchoEchoStringResponse
Converts the given reference to this type.
Sourceimpl Hash for EchoEchoStringResponse
impl Hash for EchoEchoStringResponse
Sourceimpl Ord for EchoEchoStringResponse
impl Ord for EchoEchoStringResponse
Sourcefn cmp(&self, other: &EchoEchoStringResponse) -> Ordering
fn cmp(&self, other: &EchoEchoStringResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EchoEchoStringResponse
impl PartialEq for EchoEchoStringResponse
Sourceimpl PartialOrd for EchoEchoStringResponse
impl PartialOrd for EchoEchoStringResponse
impl Eq for EchoEchoStringResponse
impl StructuralPartialEq for EchoEchoStringResponse