pub struct TicTacToeMakeMoveResponse {
pub success: bool,
pub new_state: Option<Box<GameState>>,
}Fields
success: boolnew_state: Option<Box<GameState>>Trait Implementations
Sourceimpl Clone for TicTacToeMakeMoveResponse
impl Clone for TicTacToeMakeMoveResponse
Sourcefn clone(&self) -> TicTacToeMakeMoveResponse
fn clone(&self) -> TicTacToeMakeMoveResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TicTacToeMakeMoveResponse> for TicTacToeMakeMoveResponse
impl CompatFrom<TicTacToeMakeMoveResponse> for TicTacToeMakeMoveResponse
Sourcefn compat_from(value: TicTacToeMakeMoveResponse) -> TicTacToeMakeMoveResponse
fn compat_from(value: TicTacToeMakeMoveResponse) -> TicTacToeMakeMoveResponse
Converts
value into a value of this type.Sourceimpl Debug for TicTacToeMakeMoveResponse
impl Debug for TicTacToeMakeMoveResponse
Sourceimpl<'a, ___E> Encode<TicTacToeMakeMoveResponse<'static>, ___E> for &'a TicTacToeMakeMoveResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<TicTacToeMakeMoveResponse<'static>, ___E> for &'a TicTacToeMakeMoveResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TicTacToeMakeMoveResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TicTacToeMakeMoveResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TicTacToeMakeMoveResponse<'static>, ___E> for TicTacToeMakeMoveResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<TicTacToeMakeMoveResponse<'static>, ___E> for TicTacToeMakeMoveResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TicTacToeMakeMoveResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TicTacToeMakeMoveResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TicTacToeMakeMoveResponse<'static>>, ___E> for &'a TicTacToeMakeMoveResponsewhere
___E: Encoder + ?Sized,
&'a TicTacToeMakeMoveResponse: Encode<TicTacToeMakeMoveResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, TicTacToeMakeMoveResponse<'static>>, ___E> for &'a TicTacToeMakeMoveResponsewhere
___E: Encoder + ?Sized,
&'a TicTacToeMakeMoveResponse: Encode<TicTacToeMakeMoveResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a TicTacToeMakeMoveResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TicTacToeMakeMoveResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a TicTacToeMakeMoveResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TicTacToeMakeMoveResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TicTacToeMakeMoveResponse<'static>>, ___E> for TicTacToeMakeMoveResponsewhere
___E: Encoder + ?Sized,
TicTacToeMakeMoveResponse: Encode<TicTacToeMakeMoveResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, TicTacToeMakeMoveResponse<'static>>, ___E> for TicTacToeMakeMoveResponsewhere
___E: Encoder + ?Sized,
TicTacToeMakeMoveResponse: Encode<TicTacToeMakeMoveResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<TicTacToeMakeMoveResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TicTacToeMakeMoveResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<TicTacToeMakeMoveResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TicTacToeMakeMoveResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<TicTacToeMakeMoveResponse<'de>> for TicTacToeMakeMoveResponse
impl<'de> FromWire<TicTacToeMakeMoveResponse<'de>> for TicTacToeMakeMoveResponse
Sourcefn from_wire(wire: TicTacToeMakeMoveResponse<'de>) -> TicTacToeMakeMoveResponse
fn from_wire(wire: TicTacToeMakeMoveResponse<'de>) -> TicTacToeMakeMoveResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TicTacToeMakeMoveResponse<'de>> for TicTacToeMakeMoveResponse
impl<'de> FromWireRef<TicTacToeMakeMoveResponse<'de>> for TicTacToeMakeMoveResponse
Sourcefn from_wire_ref(
wire: &TicTacToeMakeMoveResponse<'de>,
) -> TicTacToeMakeMoveResponse
fn from_wire_ref( wire: &TicTacToeMakeMoveResponse<'de>, ) -> TicTacToeMakeMoveResponse
Converts the given reference to this type.
Sourceimpl Hash for TicTacToeMakeMoveResponse
impl Hash for TicTacToeMakeMoveResponse
Sourceimpl Ord for TicTacToeMakeMoveResponse
impl Ord for TicTacToeMakeMoveResponse
Sourcefn cmp(&self, other: &TicTacToeMakeMoveResponse) -> Ordering
fn cmp(&self, other: &TicTacToeMakeMoveResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for TicTacToeMakeMoveResponse
impl PartialOrd for TicTacToeMakeMoveResponse
impl Eq for TicTacToeMakeMoveResponse
impl StructuralPartialEq for TicTacToeMakeMoveResponse